@@ -116,7 +116,7 @@ class AgentClient(object):
             self.websocket_connect.send(message)
 
     def send_text_message(self, header, body):
-        text_message = Message(header, body)
+        text_message = Message(header, body, self)
         if text_message.is_valid():
             self.send_message(text_message.get_package_string())
 
