@@ -188,7 +188,7 @@ class Body(object):
                 if "code" not in content.keys():
                     raise Exception("Key 'code' not exist in content, but must input")
                 if "params" not in content.keys():
-                    self.content['params'] = dict()
+                    content['params'] = dict()
                 self.content = CmdContent(content['code'], content['params'])
             elif self.messageType == "text":
                 if "text" not in content.keys():
